/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.media.object.apio.internal.helper;

import com.liferay.apio.architect.file.BinaryFile;
import com.liferay.document.library.kernel.service.DLAppService;
import com.liferay.media.object.apio.internal.architect.form.MediaObjectCreatorForm;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.repository.model.FileEntry;
import com.liferay.portal.kernel.service.ServiceContext;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * Provides helper method for creating fileEntries from different Apio forms.
 *
 * @author Eduardo Perez
 * @review
 */
@Component(immediate = true, service = MediaObjectHelper.class)
public class MediaObjectHelper {

	/**
	 * Adds a file entry and associated metadata. It is created based on a
	 * {@link MediaObjectCreatorForm} object.
	 *
	 * @param  repositoryId the repository ID in which to add the file entry
	 * @param  folderId the folder ID in which to add the folder
	 * @param  mediaObjectCreatorForm the form with the new file entry data
	 * @return the created file entry
	 * @throws PortalException if an error occurred while adding the file entry
	 * @review
	 */
	public FileEntry addFileEntry(
			long repositoryId, long folderId,
			MediaObjectCreatorForm mediaObjectCreatorForm)
		throws PortalException {

		BinaryFile binaryFile = mediaObjectCreatorForm.getBinaryFile();

		return _dlAppService.addFileEntry(
			repositoryId, folderId, mediaObjectCreatorForm.getName(),
			binaryFile.getMimeType(), mediaObjectCreatorForm.getTitle(),
			mediaObjectCreatorForm.getDescription(),
			mediaObjectCreatorForm.getChangelog(), binaryFile.getInputStream(),
			binaryFile.getSize(), new ServiceContext());
	}

	@Reference
	private DLAppService _dlAppService;

}